You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@spark.apache.org by va...@apache.org on 2018/05/16 20:35:00 UTC

spark git commit: [SPARK-23601][BUILD][FOLLOW-UP] Keep md5 checksums for nexus artifacts.

Repository: spark
Updated Branches:
  refs/heads/master 6fb7d6c4f -> 8e60a16b7


[SPARK-23601][BUILD][FOLLOW-UP] Keep md5 checksums for nexus artifacts.

The repository.apache.org server still requires md5 checksums or
it won't publish the staging repo.

Author: Marcelo Vanzin <va...@cloudera.com>

Closes #21338 from vanzin/SPARK-23601.


Project: http://git-wip-us.apache.org/repos/asf/spark/repo
Commit: http://git-wip-us.apache.org/repos/asf/spark/commit/8e60a16b
Tree: http://git-wip-us.apache.org/repos/asf/spark/tree/8e60a16b
Diff: http://git-wip-us.apache.org/repos/asf/spark/diff/8e60a16b

Branch: refs/heads/master
Commit: 8e60a16b73490007fe1c480d77cc09d760f0a02b
Parents: 6fb7d6c
Author: Marcelo Vanzin <va...@cloudera.com>
Authored: Wed May 16 13:34:54 2018 -0700
Committer: Marcelo Vanzin <va...@cloudera.com>
Committed: Wed May 16 13:34:54 2018 -0700

----------------------------------------------------------------------
 dev/create-release/release-build.sh | 9 ++++++++-
 1 file changed, 8 insertions(+), 1 deletion(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/spark/blob/8e60a16b/dev/create-release/release-build.sh
----------------------------------------------------------------------
diff --git a/dev/create-release/release-build.sh b/dev/create-release/release-build.sh
index c00b00b..5faa3d3 100755
--- a/dev/create-release/release-build.sh
+++ b/dev/create-release/release-build.sh
@@ -371,11 +371,18 @@ if [[ "$1" == "publish-release" ]]; then
   find . -type f |grep -v \.jar |grep -v \.pom | xargs rm
 
   echo "Creating hash and signature files"
   # this must have .asc and .sha1 - it really doesn't like anything else there
   for file in $(find . -type f)
   do
     echo $GPG_PASSPHRASE | $GPG --passphrase-fd 0 --output $file.asc \
       --detach-sig --armour $file;
+    if [ $(command -v md5) ]; then
+      # Available on OS X; -q to keep only hash
+      md5 -q $file > $file.md5
+    else
+      # Available on Linux; cut to keep only hash
+      md5sum $file | cut -f1 -d' ' > $file.md5
+    fi
     sha1sum $file | cut -f1 -d' ' > $file.sha1
   done
 


---------------------------------------------------------------------
@@ -371,11 +371,18 @@ if [[ "$1" == "publish-release" ]]; then
 
   echo "Creating hash and signature files"
-  # this must have .asc and .sha1 - it really doesn't like anything else there
+  # this must have .asc, .md5 and .sha1 - it really doesn't like anything else there
   for file in $(find . -type f)
   do
To unsubscribe, e-mail: commits-unsubscribe@spark.apache.org
For additional commands, e-mail: commits-help@spark.apache.org